@@ -7,10 +7,15 @@ function(objeto){
 	y <- objeto$y
 	v <- objeto$v
 	alpha <- objeto$xi[1]
-	dg2 <- 2 + 4/(alpha^2) - (sqrt(2*pi)/alpha)*(1-2*(pnorm(sqrt(2)/alpha,mean=0,sd=sqrt(2)/2)-0.5))*exp(2/(alpha^2))
+	dg2 <- function(alphas){
+			2 + 4/(alphas^2) - (sqrt(2*pi)/alphas)*(1-2*(pnorm(sqrt(2)/alphas,mean=0,sd=sqrt(2)/2)-0.5))*exp(2/(alphas^2))
+	}
+	fg2 <- function(alphas){
+		  (2.071 + alphas*(1.936)      + alphas^2*(-6.003e-02) + alphas^3*(1.337e-03)  + alphas^4*(-1.748e-05) + alphas^5*(1.202e-07) + alphas^6*(-3.343e-10))*(alphas>2) + 
+		  (3.001 + alphas*(-1.030e-02) + alphas^2*(1.050)      + alphas^3*(-8.828e-02) + alphas^4*(-1.859e-01) + alphas^5*(8.899e-02) + alphas^6*(-1.327e-02))*(alphas<=2)
+	}
 	family <- objeto$family
 	W_bar <- objeto$W_bar
-	K_psi2 <- objeto$K_psi2
 	theta_new <- objeto$theta_work
 	tol_EM <- 1
 	cont <- 0
@@ -32,6 +37,10 @@ if(p>0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
+			Kpsim <- matrix(0,l+q,l+q)
+	        Kpsim[(l+1):(l+q),(l+1):(l+q)] <- objeto$lambda.phi*objeto$M
 		    while(tol_EM > objeto$epsilon){
 				theta <- theta_new
 			  	beta <- theta[1:p]
@@ -44,10 +53,11 @@ if(p>0){
 				psi <- theta[(p+1):length(theta)]
 				U_psi <- (1/2)*t(W_bar)%*%(v2(z)*z^2-1)
 				U_psi[(l+1):length(psi)] <- U_psi[(l+1):length(psi)] - objeto$lambda.phi*objeto$M%*%h
-			    D2 <- D*matrix(1/phi,length(phi),p)
+			    D2 <- D*matrix(dgs/phi,length(phi),p)
 			    D3 <- D*matrix(v2(z)/phi,length(phi),p)			
-				beta_new <- beta + (1/dg2)*solve(t(D)%*%D2)%*%t(D3)%*%(y-mus)
-			    psi_new <- psi +  K_psi2%*%U_psi
+				beta_new <- beta + solve(t(D)%*%D2)%*%t(D3)%*%(y-mus)
+			    W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			    psi_new <- psi +  solve(t(W_bar)%*%W_bar2 + Kpsim)%*%U_psi
 	    		theta_new <- c(t(beta_new),t(psi_new))
 	    		theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 			    tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -70,6 +80,8 @@ if(p>0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
 	  	    while(tol_EM > objeto$epsilon){
 				 theta <- theta_new
 		  	     beta <- theta[1:p]
@@ -80,10 +92,11 @@ if(p>0){
 				 psi <- theta[(p+1):length(theta)]
 				 U_psi <- (1/2)*t(W_bar)%*%(v2(z)*z^2-1)
 	    		 D <- objeto$GradD(theta)[objeto$subset,]
-	 		     D2 <- D*matrix(1/phi,length(phi),p)
+	 		     D2 <- D*matrix(dgs/phi,length(phi),p)
 			     D3 <- D*matrix(v2(z)/phi,length(phi),p)
-				 beta_new <- beta + (1/dg2)*solve(t(D)%*%D2)%*%t(D3)%*%(y-mus)
-			     psi_new <- psi +  K_psi2%*%U_psi
+				 beta_new <- beta + solve(t(D)%*%D2)%*%t(D3)%*%(y-mus)
+			     W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			     psi_new <- psi + solve(t(W_bar)%*%W_bar2)%*%U_psi
 	     		 theta_new <- c(t(beta_new),t(psi_new))
 	    		 theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 		    	 tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -108,7 +121,11 @@ if(p>0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
-		    while(tol_EM > objeto$epsilon){
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
+			Kpsim <- matrix(0,l+q,l+q)
+	        Kpsim[(l+1):(l+q),(l+1):(l+q)] <- objeto$lambda.phi*objeto$M
+			while(tol_EM > objeto$epsilon){
 				theta <- theta_new
 				beta <- theta[1:p]
 			    mus <- objeto$mu(beta)[objeto$subset]
@@ -118,10 +135,11 @@ if(p>0){
 				psi <- theta[(p+1):length(theta)]
 				U_psi <- (1/2)*t(W_bar)%*%(v2(z)*z^2-1) - objeto$lambda.phi*objeto$M%*%h
 				D <- objeto$GradD(theta)[objeto$subset,]
-			    D2 <- D*matrix(1/phi,length(phi),p)
+			    D2 <- D*matrix(dgs/phi,length(phi),p)
 			    D3 <- D*matrix(v2(z)/phi,length(phi),p)			
-				beta_new <- beta + (1/dg2)*solve(t(D)%*%D2)%*%t(D3)%*%(y-mus)
-				psi_new <- psi +  K_psi2%*%U_psi
+				beta_new <- beta + solve(t(D)%*%D2)%*%t(D3)%*%(y-mus)
+			    W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			    psi_new <- psi +  solve(t(W_bar)%*%W_bar2 + Kpsim)%*%U_psi
 	    		theta_new <- c(t(beta_new),t(psi_new))
 	   		    theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 			    tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -154,7 +172,11 @@ if(p>0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
-		    while(tol_EM > objeto$epsilon){
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
+			Kpsim <- matrix(0,l+q,l+q)
+	        Kpsim[(l+1):(l+q),(l+1):(l+q)] <- objeto$lambda.phi*objeto$M
+			while(tol_EM > objeto$epsilon){
 				theta <- theta_new
 			  	beta <- theta[1:p]
 			    mus <- objeto$mu(beta)[objeto$subset]
@@ -169,7 +191,8 @@ if(p>0){
 			    D2 <- D_bar*matrix(1/phi,length(phi),p+qm)
 			    D3 <- D_bar*matrix(v2(z)/phi,length(phi),p+qm)			
 				beta_new <- theta[1:(p+qm)] + solve(dg2*t(D_bar)%*%D2 + Kpqm)%*%(t(D3)%*%(y-mus-objeto$Nm%*%hm) - rbind(matrix(0,p,1),objeto$lambda.mu*objeto$Mm%*%hm))
-			    psi_new <- psi +  K_psi2%*%U_psi
+			    W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			    psi_new <- psi +  solve(t(W_bar)%*%W_bar2 + Kpsim)%*%U_psi
 	    		theta_new <- c(t(beta_new),t(psi_new))
 	    		theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 			    tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -193,6 +216,8 @@ if(p>0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
 	  	    while(tol_EM > objeto$epsilon){
 				 theta <- theta_new
 		  	     beta <- theta[1:p]
@@ -206,7 +231,8 @@ if(p>0){
 	 		     D2 <- D_bar*matrix(1/phi,length(phi),p+qm)
 			     D3 <- D_bar*matrix(v2(z)/phi,length(phi),p+qm)			
 				 beta_new <- theta[1:(p+qm)] + solve(dg2*t(D_bar)%*%D2 + Kpqm)%*%(t(D3)%*%(y-mus-objeto$Nm%*%hm) - rbind(matrix(0,p,1),objeto$lambda.mu*objeto$Mm%*%hm))
-			     psi_new <- psi +  K_psi2%*%U_psi
+			     W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			     psi_new <- psi + solve(t(W_bar)%*%W_bar2)%*%U_psi
 	     		 theta_new <- c(t(beta_new),t(psi_new))
 	    		 theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 		    	 tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -232,7 +258,11 @@ if(p>0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
-		    while(tol_EM > objeto$epsilon){
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
+			Kpsim <- matrix(0,l+q,l+q)
+	        Kpsim[(l+1):(l+q),(l+1):(l+q)] <- objeto$lambda.phi*objeto$M
+			while(tol_EM > objeto$epsilon){
 				theta <- theta_new
 				beta <- theta[1:p]
 			    mus <- objeto$mu(beta)
@@ -245,7 +275,8 @@ if(p>0){
 			    D2 <- D_bar*matrix(1/phi,length(phi),p+qm)
 			    D3 <- D_bar*matrix(v2(z)/phi,length(phi),p+qm)			
 			    beta_new <- theta[1:(p+qm)] + solve(dg2*t(D_bar)%*%D2 + Kpqm)%*%(t(D3)%*%(y-mus-objeto$Nm%*%hm) - rbind(matrix(0,p,1),objeto$lambda.mu*objeto$Mm%*%hm))
-				psi_new <- psi +  K_psi2%*%U_psi
+			    W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			    psi_new <- psi +  solve(t(W_bar)%*%W_bar2 + Kpsim)%*%U_psi
 	    		theta_new <- c(t(beta_new),t(psi_new))
 	   		    theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 			    tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -276,7 +307,11 @@ if(p==0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
-		    while(tol_EM > objeto$epsilon){
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
+			Kpsim <- matrix(0,l+q,l+q)
+	        Kpsim[(l+1):(l+q),(l+1):(l+q)] <- objeto$lambda.phi*objeto$M
+			while(tol_EM > objeto$epsilon){
 				theta <- theta_new
 				hm <- objeto$theta_work[(p+1):(p+qm)]			
 		    	gammav <- theta[(p+qm+1):(p+qm+l)]
@@ -289,7 +324,8 @@ if(p==0){
 			    D2 <- D_bar*matrix(1/phi,length(phi),p+qm)
 			    D3 <- D_bar*matrix(v2(z)/phi,length(phi),p+qm)			
 				beta_new <- theta[1:(p+qm)] + solve(dg2*t(D_bar)%*%D2 + objeto$lambda.mu*objeto$Mm)%*%(t(D3)%*%(y-objeto$Nm%*%hm) - objeto$lambda.mu*objeto$Mm%*%hm)
-			    psi_new <- psi +  K_psi2%*%U_psi
+			    W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			    psi_new <- psi +  solve(t(W_bar)%*%W_bar2 + Kpsim)%*%U_psi
 	    		theta_new <- c(t(beta_new),t(psi_new))
 	    		theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 			    tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -312,6 +348,8 @@ if(p==0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
 	  	    while(tol_EM > objeto$epsilon){
 				 theta <- theta_new
 		  	     beta <- theta[1:p]
@@ -324,7 +362,8 @@ if(p==0){
 	 		     D2 <- D_bar*matrix(1/phi,length(phi),p+qm)
 			     D3 <- D_bar*matrix(v2(z)/phi,length(phi),p+qm)			
 				 beta_new <- theta[1:(p+qm)] + solve(dg2*t(D_bar)%*%D2 + objeto$lambda.mu*objeto$Mm)%*%(t(D3)%*%(y-objeto$Nm%*%hm) - objeto$lambda.mu*objeto$Mm%*%hm)
-			     psi_new <- psi +  K_psi2%*%U_psi
+			     W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			     psi_new <- psi + solve(t(W_bar)%*%W_bar2)%*%U_psi
 	     		 theta_new <- c(t(beta_new),t(psi_new))
 	    		 theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 		    	 tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
@@ -349,7 +388,11 @@ if(p==0){
 			v2 <- function(z){
 		          4*sinh(z)*cosh(z)*u_work/(alpha^2*z) - tanh(z)/z
 		    }
-		    while(tol_EM > objeto$epsilon){
+			dgs <- dg2(alpha/sqrt(u_work))
+			fgs <- fg2(alpha/sqrt(u_work))
+			Kpsim <- matrix(0,l+q,l+q)
+	        Kpsim[(l+1):(l+q),(l+1):(l+q)] <- objeto$lambda.phi*objeto$M
+			while(tol_EM > objeto$epsilon){
 				theta <- theta_new
 	            hm <- theta[(p+1):(p+qm)]
 				h <- theta[(p+qm+1):length(theta)]
@@ -360,7 +403,8 @@ if(p==0){
 			    D2 <- D_bar*matrix(1/phi,length(phi),p+qm)
 			    D3 <- D_bar*matrix(v2(z)/phi,length(phi),p+qm)			
 			    beta_new <- theta[1:(p+qm)] + solve(dg2*t(D_bar)%*%D2 + objeto$lambda.mu*objeto$Mm)%*%(t(D3)%*%(y-objeto$Nm%*%hm) - objeto$lambda.mu*objeto$Mm%*%hm)
-				psi_new <- psi +  K_psi2%*%U_psi
+			    W_bar2 <- W_bar*matrix((fgs-1)/4,length(phi),ncol(W_bar))
+			    psi_new <- psi +  solve(t(W_bar)%*%W_bar2 + Kpsim)%*%U_psi
 	    		theta_new <- c(t(beta_new),t(psi_new))
 	   		    theta_pd <- ifelse(theta==rep(0,length(theta)),1,theta)
 			    tol_EM <- max(abs(theta_new-theta)/abs(theta_pd))
